gpu_timer_features

Function gpu_timer_features 

pub(crate) fn gpu_timer_features() -> Features
Available on crate feature preview only.
GPU timer features requested from eframe’s device so wgpu-profiler scopes produce results (intersected with adapter support at the call site, so device creation can never fail because of them).