pub(crate) fn gpu_timer_features() -> FeaturesAvailable on crate feature
preview only.Expand description
GPU timer features requested from eframe’s device so wgpu-profiler scopes produce results (intersected with adapter support at the call site, so device creation can never fail because of them).